==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GeographicTileSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { GeographicShapeSeriesBaseDescription } from "./GeographicShapeSeriesBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var GeographicTileSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicTileSeriesDescription, _super);
    function GeographicTileSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.dt = null;
        _this.dv = null;
        return _this;
    }
    GeographicTileSeriesDescription.prototype.get_type = function () {
        return "GeographicTileSeries";
    };
    Object.defineProperty(GeographicTileSeriesDescription.prototype, "tileImagery", {
        get: function () {
            return this.dt;
        },
        set: function (a) {
            this.dt = a;
            this.e("TileImagery");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicTileSeriesDescription.prototype, "imageTilesReadyRef", {
        get: function () {
            return this.dv;
        },
        set: function (a) {
            this.dv = a;
            this.e("ImageTilesReadyRef");
        },
        enumerable: false,
        configurable: true
    });
    GeographicTileSeriesDescription.$t = markType(GeographicTileSeriesDescription, 'GeographicTileSeriesDescription', GeographicShapeSeriesBaseDescription.$);
    return GeographicTileSeriesDescription;
}(GeographicShapeSeriesBaseDescription));
export { GeographicTileSeriesDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/GeographicTileSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { GeographicShapeSeriesBaseDescription } from "./GeographicShapeSeriesBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var GeographicTileSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicTileSeriesDescription, _super);
    function GeographicTileSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.fz = null;
        _this.f1 = null;
        return _this;
    }
    GeographicTileSeriesDescription.prototype.get_type = function () {
        return "GeographicTileSeries";
    };
    Object.defineProperty(GeographicTileSeriesDescription.prototype, "tileImagery", {
        get: function () {
            return this.fz;
        },
        set: function (a) {
            this.fz = a;
            this.g("TileImagery");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GeographicTileSeriesDescription.prototype, "imageTilesReadyRef", {
        get: function () {
            return this.f1;
        },
        set: function (a) {
            this.f1 = a;
            this.g("ImageTilesReadyRef");
        },
        enumerable: false,
        configurable: true
    });
    GeographicTileSeriesDescription.$t = markType(GeographicTileSeriesDescription, 'GeographicTileSeriesDescription', GeographicShapeSeriesBaseDescription.$);
    return GeographicTileSeriesDescription;
}(GeographicShapeSeriesBaseDescription));
export { GeographicTileSeriesDescription };
